/** @odoo-module **/

import {
    afterNextRender,
    start,
} from '@mail/../tests/helpers/test_utils';

QUnit.module('mail', {}, function () {
QUnit.module('components', {}, function () {
QUnit.module('partner_im_status_icon_tests.js');

QUnit.test('initially online', async function (assert) {
    assert.expect(3);

    const { createRootMessagingComponent, messaging } = await start();
    const partner = messaging.models['Partner'].create({
        id: 7,
        name: "Demo User",
        im_status: 'online',
    });
    await createRootMessagingComponent('PartnerImStatusIcon', { partner });
    assert.strictEqual(
        document.querySelectorAll(`.o_PartnerImStatusIcon`).length,
        1,
        "should have partner IM status icon"
    );
    assert.strictEqual(
        document.querySelector(`.o_PartnerImStatusIcon`).dataset.partnerLocalId,
        partner.localId,
        "partner IM status icon should be linked to partner with ID 7"
    );
    assert.strictEqual(
        document.querySelectorAll(`.o_PartnerImStatusIcon.o-online`).length,
        1,
        "partner IM status icon should have online status rendering"
    );
});

QUnit.test('initially offline', async function (assert) {
    assert.expect(1);

    const { createRootMessagingComponent, messaging } = await start();
    const partner = messaging.models['Partner'].create({
        id: 7,
        name: "Demo User",
        im_status: 'offline',
    });
    await createRootMessagingComponent('PartnerImStatusIcon', { partner });
    assert.strictEqual(
        document.querySelectorAll(`.o_PartnerImStatusIcon.o-offline`).length,
        1,
        "partner IM status icon should have offline status rendering"
    );
});

QUnit.test('initially away', async function (assert) {
    assert.expect(1);

    const { createRootMessagingComponent, messaging } = await start();
    const partner = messaging.models['Partner'].create({
        id: 7,
        name: "Demo User",
        im_status: 'away',
    });
    await createRootMessagingComponent('PartnerImStatusIcon', { partner });
    assert.strictEqual(
        document.querySelectorAll(`.o_PartnerImStatusIcon.o-away`).length,
        1,
        "partner IM status icon should have away status rendering"
    );
});

QUnit.test('change icon on change partner im_status', async function (assert) {
    assert.expect(4);

    const { createRootMessagingComponent, messaging } = await start();
    const partner = messaging.models['Partner'].create({
        id: 7,
        name: "Demo User",
        im_status: 'online',
    });
    await createRootMessagingComponent('PartnerImStatusIcon', { partner });
    assert.strictEqual(
        document.querySelectorAll(`.o_PartnerImStatusIcon.o-online`).length,
        1,
        "partner IM status icon should have online status rendering"
    );

    await afterNextRender(() => partner.update({ im_status: 'offline' }));
    assert.strictEqual(
        document.querySelectorAll(`.o_PartnerImStatusIcon.o-offline`).length,
        1,
        "partner IM status icon should have offline status rendering"
    );

    await afterNextRender(() => partner.update({ im_status: 'away' }));
    assert.strictEqual(
        document.querySelectorAll(`.o_PartnerImStatusIcon.o-away`).length,
        1,
        "partner IM status icon should have away status rendering"
    );

    await afterNextRender(() => partner.update({ im_status: 'online' }));
    assert.strictEqual(
        document.querySelectorAll(`.o_PartnerImStatusIcon.o-online`).length,
        1,
        "partner IM status icon should have online status rendering in the end"
    );
});

});
});
